@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # ********************************************************************
 #
-#  $Id: yocto_lightsensor.py 38899 2019-12-20 17:21:03Z mvuilleu $
+#  $Id: yocto_lightsensor.py 42951 2020-12-14 09:43:29Z seb $
 #
 #  Implements yFindLightSensor(), the high-level API for LightSensor functions
 #
@@ -69,6 +69,7 @@ class YLightSensor(YSensor):
     MEASURETYPE_INFRARED = 2
     MEASURETYPE_HIGH_RATE = 3
     MEASURETYPE_HIGH_ENERGY = 4
+    MEASURETYPE_HIGH_RESOLUTION = 5
     MEASURETYPE_INVALID = -1
     #--- (end of YLightSensor definitions)
 
@@ -112,8 +113,9 @@ class YLightSensor(YSensor):
         Returns the type of light measure.
 
         @return a value among YLightSensor.MEASURETYPE_HUMAN_EYE, YLightSensor.MEASURETYPE_WIDE_SPECTRUM,
-        YLightSensor.MEASURETYPE_INFRARED, YLightSensor.MEASURETYPE_HIGH_RATE and
-        YLightSensor.MEASURETYPE_HIGH_ENERGY corresponding to the type of light measure
+        YLightSensor.MEASURETYPE_INFRARED, YLightSensor.MEASURETYPE_HIGH_RATE,
+        YLightSensor.MEASURETYPE_HIGH_ENERGY and YLightSensor.MEASURETYPE_HIGH_RESOLUTION corresponding to
+        the type of light measure
 
         On failure, throws an exception or returns YLightSensor.MEASURETYPE_INVALID.
         """
@@ -134,8 +136,8 @@ class YLightSensor(YSensor):
 
         @param newval : a value among YLightSensor.MEASURETYPE_HUMAN_EYE,
         YLightSensor.MEASURETYPE_WIDE_SPECTRUM, YLightSensor.MEASURETYPE_INFRARED,
-        YLightSensor.MEASURETYPE_HIGH_RATE and YLightSensor.MEASURETYPE_HIGH_ENERGY corresponding to the
-        light sensor type used in the device
+        YLightSensor.MEASURETYPE_HIGH_RATE, YLightSensor.MEASURETYPE_HIGH_ENERGY and
+        YLightSensor.MEASURETYPE_HIGH_RESOLUTION corresponding to the light sensor type used in the device
 
         @return YAPI.SUCCESS if the call succeeds.
 
