@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # ********************************************************************
 #
-#  $Id: yocto_spiport.py 40298 2020-05-05 08:37:49Z seb $
+#  $Id: yocto_spiport.py 41171 2020-07-02 17:49:00Z mvuilleu $
 #
 #  Implements yFindSpiPort(), the high-level API for SpiPort functions
 #
@@ -43,7 +43,62 @@ __docformat__ = 'restructuredtext en'
 from yoctopuce.yocto_api import *
 
 
-#--- (YSpiPort class start)
+#--- (generated code: YSpiSnoopingRecord class start)
+#noinspection PyProtectedMember
+class YSpiSnoopingRecord(object):
+    #--- (end of generated code: YSpiSnoopingRecord class start)
+    #--- (generated code: YSpiSnoopingRecord definitions)
+    #--- (end of generated code: YSpiSnoopingRecord definitions)
+
+    def __init__(self, json_str):
+        #--- (generated code: YSpiSnoopingRecord attributes)
+        self._tim = 0
+        self._dir = 0
+        self._msg = ''
+        #--- (end of generated code: YSpiSnoopingRecord attributes)
+        json = YJSONObject(json_str, 0, len(json_str))
+        json.parse()
+        self._tim = json.getInt("t")
+        m = json.getString("m")
+        if m[0] == '<':
+            self._dir = 1
+        else:
+            self._dir = 0
+        self._msg = m[1:]
+
+    #--- (generated code: YSpiSnoopingRecord implementation)
+    def get_time(self):
+        """
+        Returns the elapsed time, in ms, since the beginning of the preceding message.
+
+        @return the elapsed time, in ms, since the beginning of the preceding message.
+        """
+        return self._tim
+
+    def get_direction(self):
+        """
+        Returns the message direction (RX=0, TX=1).
+
+        @return the message direction (RX=0, TX=1).
+        """
+        return self._dir
+
+    def get_message(self):
+        """
+        Returns the message content.
+
+        @return the message content.
+        """
+        return self._msg
+
+#--- (end of generated code: YSpiSnoopingRecord implementation)
+
+#--- (generated code: YSpiSnoopingRecord functions)
+#--- (end of generated code: YSpiSnoopingRecord functions)
+
+
+
+#--- (generated code: YSpiPort class start)
 #noinspection PyProtectedMember
 class YSpiPort(YFunction):
     """
@@ -54,14 +109,14 @@ class YSpiPort(YFunction):
     They are meant to be used in the same way as all Yoctopuce devices.
 
     """
-    #--- (end of YSpiPort class start)
-    #--- (YSpiPort return codes)
-    #--- (end of YSpiPort return codes)
-    #--- (YSpiPort dlldef)
-    #--- (end of YSpiPort dlldef)
-    #--- (YSpiPort yapiwrapper)
-    #--- (end of YSpiPort yapiwrapper)
-    #--- (YSpiPort definitions)
+    #--- (end of generated code: YSpiPort class start)
+    #--- (generated code: YSpiPort return codes)
+    #--- (end of generated code: YSpiPort return codes)
+    #--- (generated code: YSpiPort dlldef)
+    #--- (end of generated code: YSpiPort dlldef)
+    #--- (generated code: YSpiPort yapiwrapper)
+    #--- (end of generated code: YSpiPort yapiwrapper)
+    #--- (generated code: YSpiPort definitions)
     RXCOUNT_INVALID = YAPI.INVALID_UINT
     TXCOUNT_INVALID = YAPI.INVALID_UINT
     ERRCOUNT_INVALID = YAPI.INVALID_UINT
@@ -90,12 +145,12 @@ class YSpiPort(YFunction):
     SHIFTSAMPLING_OFF = 0
     SHIFTSAMPLING_ON = 1
     SHIFTSAMPLING_INVALID = -1
-    #--- (end of YSpiPort definitions)
+    #--- (end of generated code: YSpiPort definitions)
 
     def __init__(self, func):
         super(YSpiPort, self).__init__(func)
         self._className = 'SpiPort'
-        #--- (YSpiPort attributes)
+        #--- (generated code: YSpiPort attributes)
         self._callback = None
         self._rxCount = YSpiPort.RXCOUNT_INVALID
         self._txCount = YSpiPort.TXCOUNT_INVALID
@@ -116,9 +171,9 @@ class YSpiPort(YFunction):
         self._rxptr = 0
         self._rxbuff = ''
         self._rxbuffptr = 0
-        #--- (end of YSpiPort attributes)
+        #--- (end of generated code: YSpiPort attributes)
 
-    #--- (YSpiPort implementation)
+    #--- (generated code: YSpiPort implementation)
     def _parseAttr(self, json_val):
         if json_val.has("rxCount"):
             self._rxCount = json_val.getInt("rxCount")
@@ -1161,6 +1216,44 @@ class YSpiPort(YFunction):
         """
         return self.sendCommand("S" + str(int(val)))
 
+    def snoopMessages(self, maxWait):
+        """
+        Retrieves messages (both direction) in the SPI port buffer, starting at current position.
+
+        If no message is found, the search waits for one up to the specified maximum timeout
+        (in milliseconds).
+
+        @param maxWait : the maximum number of milliseconds to wait for a message if none is found
+                in the receive buffer.
+
+        @return an array of YSpiSnoopingRecord objects containing the messages found, if any.
+
+        On failure, throws an exception or returns an empty array.
+        """
+        # url
+        # msgbin
+        msgarr = []
+        # msglen
+        res = []
+        # idx
+
+        url = "rxmsg.json?pos=" + str(int(self._rxptr)) + "&maxw=" + str(int(maxWait)) + "&t=0"
+        msgbin = self._download(url)
+        msgarr = self._json_get_array(msgbin)
+        msglen = len(msgarr)
+        if msglen == 0:
+            return res
+        # // last element of array is the new position
+        msglen = msglen - 1
+        self._rxptr = YAPI._atoi(msgarr[msglen])
+        idx = 0
+
+        while idx < msglen:
+            res.append(YSpiSnoopingRecord(msgarr[idx]))
+            idx = idx + 1
+
+        return res
+
     def nextSpiPort(self):
         """
         Continues the enumeration of SPI ports started using yFirstSpiPort().
@@ -1179,9 +1272,9 @@ class YSpiPort(YFunction):
             return None
         return YSpiPort.FindSpiPort(hwidRef.value)
 
-#--- (end of YSpiPort implementation)
+#--- (end of generated code: YSpiPort implementation)
 
-#--- (YSpiPort functions)
+#--- (generated code: YSpiPort functions)
 
     @staticmethod
     def FirstSpiPort():
@@ -1215,4 +1308,4 @@ class YSpiPort(YFunction):
 
         return YSpiPort.FindSpiPort(serialRef.value + "." + funcIdRef.value)
 
-#--- (end of YSpiPort functions)
+#--- (end of generated code: YSpiPort functions)
